#
# spec file for package ghc-text
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global pkg_name text
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        1.2.2.2
Release:        lp150.1.8
Summary:        An efficient packed Unicode text type
License:        BSD-2-Clause
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-array-devel
BuildRequires:  ghc-binary-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-deepseq-devel
BuildRequires:  ghc-rpm-macros
%if %{with tests}
BuildRequires:  ghc-HUnit-devel
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-quickcheck-unicode-devel
BuildRequires:  ghc-random-devel
BuildRequires:  ghc-test-framework-devel
BuildRequires:  ghc-test-framework-hunit-devel
BuildRequires:  ghc-test-framework-quickcheck2-devel
%endif

%description
An efficient packed, immutable Unicode text type (both strict and lazy), with a
powerful loop fusion optimization framework.

The 'Text' type represents Unicode character strings, in a time and
space-efficient manner. This package provides text processing capabilities that
are optimized for performance critical use, both in terms of large data
quantities and high speed.

The 'Text' type provides character-encoding, type-safe case conversion via
whole-string case conversion functions. It also provides a range of functions
for converting 'Text' values to and from 'ByteStrings', using several standard
encodings.

Efficient locale-sensitive support for text IO is also supported.

These modules are intended to be imported qualified, to avoid name clashes with
Prelude functions, e.g.

> import qualified Data.Text as T

To use an extended and very rich family of functions for working with Unicode
text (including normalization, regular expressions, non-standard encodings,
text breaking, and locales), see the 'text-icu' package:
<http://hackage.haskell.org/package/text-icu>.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Haskell
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%doc LICENSE

%files devel -f %{name}-devel.files
%doc README.markdown changelog.md

%changelog
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Thu Jul 27 2017 psimons@suse.com
- Update to version 1.2.2.2.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 1.2.2.1 revision 0 with cabal2obs.
* Sat Mar 19 2016 mimi.vx@gmail.com
- update to 1.2.2.1
  * The switch to integer-pure in 1.2.2.0 was apparently mistaken. The build flag has
    been renamed accordingly. Your army of diligent maintainers apologizes
  for the churn.
  * Spec compliance: toCaseFold now follows the Unicode 8.0 spec (updated from 7.0)
  * An STG lint error has been fixed
* Thu Dec 24 2015 mimi.vx@gmail.com
- update to 1.2.2.0
  * The integer-simple package, upon which this package optionally depended, has been
  replaced with integer-pure. The build flag has been renamed accordingly.
  * Bug fix: For the Binary instance, If UTF-8 decoding fails during a get, the error
  is propagated via fail instead of an uncatchable crash.
  * New function: takeWhileEnd
  * New instances for the Text types:
  + if base >= 4.7: PrintfArg
  + if base >= 4.9: Semigroup
* Fri Aug  7 2015 mimi.vx@gmail.com
- update to 1.2.1.3
  * Bug fix: As it turns out, moving the literal rewrite rules to simplifier phase 2
  does not prevent competition with the unpack rule, which is also active in this phase.
  Unfortunately this was hidden due to a silly test environment mistake. Moving literal
  rules back to phase 1 finally fixes GHC Trac #10528 correctly.
  * Bug fix: Run literal rewrite rules in simplifier phase 2. The behavior of the simplifier
  changed in GHC 7.10.2, causing these rules to fail to fire, leading to poor code
  generation and long compilation times. See GHC Trac #10528.
  * Expose unpackCString#, which you should never use.
  * Added Binary instances for both Text types. (If you have previously been using
  the text-binary package to get a Binary instance, it is now obsolete.)
* Sun May 17 2015 mimi.vx@gmail.com
- update to 1.2.0.6
  * Feature parity: repeat, cycle, iterate are now implemented for lazy
  Text, and the Data instance is more complete
  * Build speed: an inliner space explosion has been fixed with toCaseFold
  * Bug fix: encoding Int to a Builder would infinite-loop if the
  integer-simple package was used
  * Deprecation: OnEncodeError and EncodeError are deprecated, as they
  are never used
  * Internals: some types that are used internally in fusion-related
  functions have moved around, been renamed, or been deleted (we don't
  bump the major version if .Internal modules change)
  * Spec compliance: toCaseFold now follows the Unicode 7.0 spec
  (updated from 6.3)
* Fri Apr 10 2015 mimi.vx@gmail.com
- update to 1.2.04
- all credits to yac jmatejka@suse.com
  * Update formatRealFloat to correspond to the definition in versions
  of base newer than 4.5 (https://github.com/bos/text/issues/105)
  * Bumped lower bound on deepseq to 1.4 for compatibility with the
  upcoming GHC 7.10
  * Fixed a buffer overflow in rendering of large Integers
  * Fixed an integer overflow in the replace function
  * Fixed a hang in lazy decodeUtf8With
  * Reduced codegen bloat caused by use of empty and single-character
  literals
  * Added an instance of IsList for GHC 7.8 and above
  * The Data.Data instance now allows gunfold to work, via a virtual
  pack constructor
  * dropEnd, takeEnd: new functions
  * Comparing the length of a Text against a number can now
  short-circuit in more cases
  * streamDecodeUtf8: fixed gh-70, did not return all unconsumed bytes
  in single-byte chunks
* Fri Sep 12 2014 peter.trommler@ohm-hochschule.de
- update to 1.1.0.0
  * no changelog
  * Haskell Platform 2014.2.0.0
* Tue Sep  2 2014 peter.trommler@ohm-hochschule.de
- regenerate spec file
* Sat Aug 23 2014 peter.trommler@ohm-hochschule.de
- enable PowerPC builds
* Mon May  6 2013 peter.trommler@ohm-hochschule.de
- update to 0.11.3.1 from upstream
  * no changelog provided
  * improved perfomance and API extensions
- drop BR ghc-extensible-extensions: no longer required and it is
  no longer part of ghc and Haskell Platform
- more transparent packaging (fewer macros)
* Thu Dec 27 2012 peter.trommler@ohm-hochschule.de
- fixed license tag
- expand macro in name tag
* Sat Nov 17 2012 peter.trommler@ohm-hochschule.de
- make service localonly for Factory submission
* Tue Oct  2 2012 peter.trommler@ohm-hochschule.de
- update to 0.11.2.3 from upstream
  * Adapt for ghc 7.6
  * optimizations
- required by Haskell Platform 2012.4.0.0
* Wed Jun  6 2012 peter.trommler@ohm-hochschule.de
- fixed license tag
* Sun Jun  3 2012 peter.trommler@ohm-hochschule.de
- update to 0.11.2.0 from upstream
  * String literals are now converted directly from the format in which GHC stores them into Text, without an intermediate transformation through String, and without inlining of conversion code at each site where a string literal is declared.- required by Haskell Platform 2012.2.0.0
* Wed Dec 28 2011 peter.trommler@ohm-hochschule.de
- Ported for platform 2011.4
* Wed Dec 14 2011 peter.trommler@ohm-hochschule.de
- Added ghc libraries BR
* Thu Dec  8 2011 peter.trommler@ohm-hochschule.de
- Fixed arches.
* Thu Dec  8 2011 peter.trommler@ohm-hochschule.de
- Initial packaging.
